@@ -1,10 +1,10 @@
 ; AisleRiot - sol.scm
 ; Copyright (C) 1998, 2003 Jonathan Blandford <jrb@mit.edu>
 ;
-; This game is free software; you can redistribute it and/or modify
+; This program is free software: you can redistribute it and/or modify
 ; it under the terms of the GNU General Public License as published by
-; the Free Software Foundation; either version 2, or (at your option)
-; any later version.
+; the Free Software Foundation, either version 3 of the License, or
+; (at your option) any later version.
 ;
 ; This program is distributed in the hope that it will be useful,
 ; but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,9 +12,7 @@
 ; GNU General Public License for more details.
 ;
 ; You should have received a copy of the GNU General Public License
-; along with this program; if not, write to the Free Software
-; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
-; USA
+; along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 (use-modules (ice-9 format))
 
@@ -230,10 +228,11 @@
 
 ;; Utilities
 
-(define (flippable? stock-slot flip-limit)
+(define (flippable? stock-slot waste-slot flip-limit)
   (or (not (empty-slot? stock-slot))
-      (< flip-limit 0)
-      (< FLIP-COUNTER flip-limit)))
+      (and (not (empty-slot? waste-slot))
+           (or (< flip-limit 0)
+               (< FLIP-COUNTER flip-limit)))))
 
 ; deal a card from the stock-slot to the waste-slot.
 ; when the stock slot is empty than the waste slot will be flipped back
@@ -242,7 +241,8 @@
 ; If the flip limit is negative, it is treated as infinite.
 (define (flip-stock stock-slot waste-slot flip-limit . rest)
   (if (empty-slot? stock-slot)
-      (and (or (< flip-limit 0)
+      (and (not (empty-slot? waste-slot))
+           (or (< flip-limit 0)
 	       (< FLIP-COUNTER flip-limit))
 	   (set! FLIP-COUNTER (+ 1 FLIP-COUNTER))
 	   (flip-deck stock-slot waste-slot))
@@ -327,6 +327,15 @@
 	(car cards))))
 
 ;; Utilities - need more of these:
+(define (suit-eq? card1 card2)
+  (eq? (get-suit card1) (get-suit card2)))
+
+(define (color-eq? card1 card2)
+  (eq? (get-color card1) (get-color card2)))
+
+(define (value-eq? card1 card2)
+  (eq? (get-value card1) (get-value card2)))
+
 (define (cards-eq? card1 card2)
   (and (eq? (get-value card1) (get-value card2))
        (eq? (get-suit card1) (get-suit card2))))
