@@ -24,8 +24,14 @@
 
 
 
-#include "config.h"
-#include <gnome.h>
+#include <config.h>
+
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
+#include <libgames-support/games-runtime.h>
+
 #include "main.h"
 #include "theme.h"
 #include "prefs.h"
@@ -137,10 +143,9 @@ gfx_draw_tile (gint r, gint c, gboolean refresh)
 		     tilesize);
 
   if (tile != TILE_CLEAR) {
-    gdk_pixbuf_render_to_drawable_alpha (pb_tileset, pm_display,
-					 os, 0, x, y, tilesize, tilesize,
-					 GDK_PIXBUF_ALPHA_BILEVEL, 128,
-					 GDK_RGB_DITHER_NORMAL, 0, 0);
+    gdk_draw_pixbuf (pm_display, NULL, pb_tileset,
+                     os, 0, x, y, tilesize, tilesize,
+                     GDK_RGB_DITHER_NORMAL, 0, 0);
   }
 
   if (refresh) {
@@ -242,11 +247,11 @@ gfx_resize (GtkWidget * w)
 void
 gfx_expose (GdkRectangle * area)
 {
-  gdk_draw_pixmap (drawarea->window,
-		   gc,
-		   pm_display,
-		   area->x, area->y,
-		   area->x, area->y, area->width, area->height);
+  gdk_draw_drawable (GDK_DRAWABLE (drawarea->window),
+                     gc,
+                     pm_display,
+                     area->x, area->y,
+                     area->x, area->y, area->width, area->height);
 }
 
 
@@ -267,23 +272,18 @@ gfx_load_error (const gchar * fname)
 }
 
 
-
 gboolean
 gfx_load_pixmaps (void)
 {
-  gchar *dname;
+  const char *dname;
   gchar *fname;
   GdkPixbuf *pb_tileset_tmp;
   GdkPixbuf *pb_bground_tmp = NULL;
 
-  dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
-				     APPNAME, FALSE, NULL);
-
+  dname = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
   /* Try the theme pixmaps, fallback to the default and then give up */
   while (TRUE) {
-    fname = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s", dname,
-			     theme[p.theme_id].fname_tileset);
-
+    fname = g_build_filename (dname, theme[p.theme_id].fname_tileset, NULL);
     pb_tileset_tmp = gdk_pixbuf_new_from_file (fname, NULL);
     if (pb_tileset_tmp == NULL) {
       if (p.theme_id != 0) {
@@ -292,7 +292,6 @@ gfx_load_pixmaps (void)
 	continue;
       } else {
 	gfx_load_error (fname);
-	g_free (dname);
 	g_free (fname);
 	return FALSE;
       }
@@ -308,21 +307,17 @@ gfx_load_pixmaps (void)
   pb_tileset_raw = pb_tileset_tmp;
 
   if (theme[p.theme_id].fname_bground != NULL) {
-    fname = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s", dname,
-			     theme[p.theme_id].fname_bground);
+    fname = g_build_filename (dname, theme[p.theme_id].fname_bground, NULL);
     pb_bground_tmp = gdk_pixbuf_new_from_file (fname, NULL);
     if (pb_bground_tmp == NULL) {
       gfx_load_error (fname);
       g_object_unref (pb_tileset_tmp);
-      g_free (dname);
       g_free (fname);
       return FALSE;
     }
     g_free (fname);
   }
 
-  g_free (dname);
-
   if (pb_bground_raw)
     g_object_unref (pb_bground_raw);
 
