@@ -15,9 +15,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#include "config.h"
-#include <gnome.h>
-#include <ggzdmod.h>
+#include <config.h>
+
 #include <sys/types.h>
 #include <errno.h>
 #include <stdio.h>
@@ -25,8 +24,8 @@
 #include <time.h>
 #include <unistd.h>
 
-#include "connect4.h"
-#include "main.h"
+#include <ggzdmod.h>
+
 #include "server.h"
 
 
