@@ -26,8 +26,6 @@
 #include <math.h>
 #include <ctype.h>
 
-#include <glib/gi18n.h>
-#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gio/gio.h>
 
@@ -43,8 +41,8 @@
 #include "scoreframe.h"
 #include "highscores.h"
 #include "preview.h"
-#include "renderer.h"
 #include "blockops.h"
+#include "renderer.h"
 
 int LINES = 20;
 int COLUMNS = 14;
@@ -56,6 +54,7 @@ int rot_next = -1;
 int color_next = -1;
 
 bool random_block_colors = false;
+bool bastard_mode = false;
 bool do_preview = true;
 bool default_bgimage = false;
 bool rotateCounterClockWise = true;
@@ -146,8 +145,7 @@ Tetris::Tetris(int cmdlLevel):
 	/* Locate our background image. */
 
 	outdir = g_build_filename (g_get_user_data_dir (), "gnometris", NULL);
-	if (!g_file_test (outdir, G_FILE_TEST_EXISTS))
-	    mkdir (outdir, 0700);
+	g_mkdir_with_parents (outdir, 0700);
 	bgPixmap = g_build_filename (outdir, "background.bin", NULL);
 	g_free (outdir);
 
@@ -215,7 +213,7 @@ Tetris::Tetris(int cmdlLevel):
 	gtk_container_add (GTK_CONTAINER (aspect_frame), field->getWidget());
 
 	gtk_widget_set_events(w, gtk_widget_get_events(w) |
-						  GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
+			      GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
 
 	GtkWidget *vb1 = gtk_vbox_new(FALSE, 0);
 	gtk_container_set_border_width(GTK_CONTAINER(vb1), 10);
@@ -242,15 +240,7 @@ Tetris::Tetris(int cmdlLevel):
 
 	themeList = NULL;
 
-	gtk_widget_show(vbox);
-	gtk_widget_show(hb);
-	gtk_widget_show(vb1);
-	gtk_widget_show(vb2);
-	gtk_widget_show(aspect_frame);
-	gtk_widget_show(field->getWidget());
-	gtk_widget_show(preview->getWidget());
-	scoreFrame->show();
-	gtk_widget_show(w);
+	gtk_widget_show_all(w);
 
 	gtk_action_set_sensitive(pause_action, FALSE);
 	gtk_action_set_sensitive(end_game_action, FALSE);
@@ -438,6 +428,8 @@ Tetris::initOptions ()
 
 	random_block_colors = confGetBoolean (KEY_OPTIONS_GROUP, KEY_RANDOM_BLOCK_COLORS, TRUE);
 
+	bastard_mode = confGetBoolean (KEY_OPTIONS_GROUP, KEY_BASTARD_MODE, FALSE);
+
 	rotateCounterClockWise = confGetBoolean (KEY_OPTIONS_GROUP, KEY_ROTATE_COUNTER_CLOCKWISE, TRUE);
 
 	line_fill_height = confGetInt (KEY_OPTIONS_GROUP, KEY_LINE_FILL_HEIGHT, 0);
@@ -476,6 +468,7 @@ Tetris::setOptions ()
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (sound_toggle), games_sound_is_enabled ());
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (do_preview_toggle), do_preview);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (random_block_colors_toggle), random_block_colors);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bastard_mode_toggle), bastard_mode);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rotate_counter_clock_wise_toggle), rotateCounterClockWise);
 
 		if (theme_preview) {
@@ -509,6 +502,13 @@ Tetris::setSelectionBlocks(GtkWidget *widget, void *d)
 				GTK_TOGGLE_BUTTON (widget)->active);
 }
 
+void
+Tetris::setBastardMode(GtkWidget *widget, void *d)
+{
+	games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_BASTARD_MODE,
+				GTK_TOGGLE_BUTTON (widget)->active);
+}
+
 void
 Tetris::setRotateCounterClockWise(GtkWidget *widget, void *d)
 {
@@ -691,6 +691,15 @@ Tetris::gameProperties(GtkAction *action, void *d)
 	gtk_box_pack_start (GTK_BOX (fvbox), t->random_block_colors_toggle,
 			    0, 0, 0);
 
+	/* bastard mode */
+	t->bastard_mode_toggle =
+		gtk_check_button_new_with_mnemonic (_("_Bastard mode"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (t->bastard_mode_toggle),
+				     bastard_mode);
+	g_signal_connect (t->bastard_mode_toggle, "clicked",
+			  G_CALLBACK (setBastardMode), d);
+	gtk_box_pack_start (GTK_BOX (fvbox), t->bastard_mode_toggle, 0, 0, 0);
+
 	/* rotate counter clock wise */
  	t->rotate_counter_clock_wise_toggle =
 		gtk_check_button_new_with_mnemonic (_("_Rotate blocks counterclockwise"));
