@@ -290,7 +290,9 @@ new_game (void)
   set_flabel (GTK_MINEFIELD (mfield));
 
   gtk_action_set_visible (pause_action, TRUE);
+  gtk_action_set_sensitive (pause_action, TRUE);
   gtk_action_set_visible (resume_action, FALSE);
+  gtk_action_set_sensitive (resume_action, FALSE);
   gtk_widget_hide (resume_container);
   gtk_widget_show (mfield_container);
 }
@@ -647,7 +649,7 @@ window_state_callback (GtkWidget * widget, GdkEventWindowState * event)
 }
 
 
-static void
+static gboolean
 pause_key_callback(GtkWidget *widget, GdkEventKey *event,
 gpointer data )
 {
@@ -658,8 +660,11 @@ gpointer data )
       resume_game_cb(NULL, NULL); // Resume the game
     else
       pause_callback(NULL, NULL, NULL); // Pause the game
+
+    return TRUE;
   }
-			
+
+  return FALSE;
 }
 
 
@@ -865,7 +870,10 @@ const char ui_description[] =
   "    </menu>"
   "    <menu action='HelpMenu'>"
   "      <menuitem action='Contents'/>"
-  "      <menuitem action='About'/>" "    </menu>" "  </menubar>" "</ui>";
+  "      <menuitem action='About'/>"
+  "    </menu>"
+  "  </menubar>"
+  "</ui>";
 
 static GtkUIManager *
 create_ui_manager (const gchar * group)
@@ -1067,12 +1075,6 @@ main (int argc, char *argv[])
 
   verify_ranges ();
 
-  /* This is evil, but the normal button focus indicator 
-   * interferes with the face (but we still want the button
-   * to be the default). */
-  gtk_rc_parse_string
-    ("style \"gnomine\" { GtkButton::interior-focus = 0 } class \"GtkButton\" style \"gnomine\"");
-
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), _(APP_NAME_LONG));
     
@@ -1094,6 +1096,7 @@ main (int argc, char *argv[])
                     G_CALLBACK (pause_key_callback), NULL); 
 
   all_boxes = gtk_vbox_new (FALSE, 0);
+  gtk_widget_show (all_boxes);
 
   gtk_container_add (GTK_CONTAINER (window), all_boxes);
 
@@ -1101,6 +1104,7 @@ main (int argc, char *argv[])
   accel_group = gtk_ui_manager_get_accel_group (ui_manager);
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
   box = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
+  gtk_widget_show (box);
   gtk_box_pack_start (GTK_BOX (all_boxes), box, FALSE, FALSE, 0);
 
   button_table = gtk_table_new (1, 3, FALSE);
@@ -1189,7 +1193,8 @@ main (int argc, char *argv[])
 
   new_game ();
 
-  gtk_widget_show_all (window);
+  gtk_widget_show_all (button_table);
+  gtk_widget_show (window);
 
   /* Must be after the window has been created. */
   if (xpos >= 0 && ypos >= 0)
