@@ -34,7 +34,6 @@
 #include <libgames-support/games-conf.h>
 #include <libgames-support/games-help.h>
 #include <libgames-support/games-runtime.h>
-#include <libgames-support/games-sound.h>
 #include <libgames-support/games-stock.h>
 
 #ifdef WITH_SMCLIENT
@@ -682,17 +681,17 @@ check_computer_players (void)
     switch (black_computer_level) {
     case 1:
       black_computer_id =
-	g_timeout_add (computer_speed, (GSourceFunc) computer_move_1,
+	add_timeout (computer_speed, (GSourceFunc) computer_move_1,
 		       (gpointer) BLACK_TURN);
       break;
     case 2:
       black_computer_id =
-	g_timeout_add (computer_speed, (GSourceFunc) computer_move_2,
+	add_timeout (computer_speed, (GSourceFunc) computer_move_2,
 		       (gpointer) BLACK_TURN);
       break;
     case 3:
       black_computer_id =
-	g_timeout_add (computer_speed, (GSourceFunc) computer_move_3,
+	add_timeout (computer_speed, (GSourceFunc) computer_move_3,
 		       (gpointer) BLACK_TURN);
       break;
     }
@@ -701,17 +700,17 @@ check_computer_players (void)
     switch (white_computer_level) {
     case 1:
       white_computer_id =
-	g_timeout_add (computer_speed, (GSourceFunc) computer_move_1,
+	add_timeout (computer_speed, (GSourceFunc) computer_move_1,
 		       (gpointer) WHITE_TURN);
       break;
     case 2:
       white_computer_id =
-	g_timeout_add (computer_speed, (GSourceFunc) computer_move_2,
+	add_timeout (computer_speed, (GSourceFunc) computer_move_2,
 		       (gpointer) WHITE_TURN);
       break;
     case 3:
       white_computer_id =
-	g_timeout_add (computer_speed, (GSourceFunc) computer_move_3,
+	add_timeout (computer_speed, (GSourceFunc) computer_move_3,
 		       (gpointer) WHITE_TURN);
       break;
     }
@@ -719,6 +718,17 @@ check_computer_players (void)
   return TRUE;
 }
 
+guint
+add_timeout (guint time, GSourceFunc func, gpointer turn)
+{
+  if (time % 1000) {
+    return g_timeout_add (time, func, turn);
+  } else {
+    time = time / 1000;
+    return g_timeout_add_seconds (time, func, turn);
+  }
+}
+
 void
 set_bg_color (void)
 {
@@ -991,7 +1001,6 @@ main (int argc, char **argv)
   g_option_context_add_group (context, egg_sm_client_get_option_group ());
 #endif /* WITH_SMCLIENT */
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
-  games_sound_add_option_group (context);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
   g_option_context_free (context);
