@@ -1,20 +1,20 @@
 /*
-   Copyright © 2004 Callum McKenzie
-   Copyright © 2007, 2008, 2009 Christian Persch
+  Copyright © 2004 Callum McKenzie
+  Copyright © 2007, 2008, 2009 Christian Persch
 
-   This library is free software; you can redistribute it and'or modify
-   it under the terms of the GNU Library General Public License as published 
-   by the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+  This library is free software: you can redistribute it and/or modify
+  it under the terms of the GNU Lesser General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+  You should have received a copy of the GNU Lesser General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 /* Authors:   Callum McKenzie <callum@physics.otago.ac.nz> */
 
