@@ -33,24 +33,10 @@
 #include <librsvg/rsvg-cairo.h>
 #endif /* HAVE_RSVG */
 
+#include "games-profile.h"
+
 #include "games-preimage.h"
-
-struct _GamesPreimage {
-  GObject parent;
-
-  gint width;
-  gint height;
-
-#ifdef HAVE_RSVG
-  RsvgHandle *rsvg_handle;
-  cairo_font_options_t *font_options;
-#endif
-
-  /* raster pixbuf data */
-  GdkPixbuf *pixbuf;
-
-  guint scalable : 1;
-};
+#include "games-preimage-private.h"
 
 G_DEFINE_TYPE (GamesPreimage, games_preimage, G_TYPE_OBJECT);
 
@@ -285,6 +271,8 @@ games_preimage_new_from_file (const gchar * filename, GError ** error)
 
   g_return_val_if_fail (filename != NULL, NULL);
 
+  _games_profile_start ("creating GamesPreimage from %s", filename);
+
   preimage = g_object_new (GAMES_TYPE_PREIMAGE, NULL);
 
 #ifdef HAVE_RSVG
@@ -296,6 +284,8 @@ games_preimage_new_from_file (const gchar * filename, GError ** error)
 
     rsvg_handle_get_dimensions (preimage->rsvg_handle, &data);
 
+    _games_profile_end ("creating GamesPreimage from %s", filename);
+
     if (data.width == 0 || data.height == 0) {
       g_set_error (error,
                    GDK_PIXBUF_ERROR,
@@ -315,6 +305,8 @@ games_preimage_new_from_file (const gchar * filename, GError ** error)
   preimage->scalable = FALSE;
 
   pixbuf = gdk_pixbuf_new_from_file (filename, error);
+  _games_profile_end ("creating GamesPreimage from %s", filename);
+
   if (!pixbuf) {
     g_object_unref (preimage);
     return NULL;
@@ -338,6 +330,7 @@ void
 games_preimage_set_font_options (GamesPreimage * preimage,
                                  const cairo_font_options_t * font_options)
 {
+#ifdef HAVE_RSVG
   g_return_if_fail (GAMES_IS_PREIMAGE (preimage));
 
   if (preimage->font_options) {
@@ -349,6 +342,7 @@ games_preimage_set_font_options (GamesPreimage * preimage,
   } else {
     preimage->font_options = NULL;
   }
+#endif /* HAVE_RSVG */
 }
 
 /**
