@@ -1,5 +1,5 @@
 /*
- *  Copyright © 2007 Christian Persch
+ *  Copyright © 2007, 2008 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,8 +14,6 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- *  $Id$
  */
 
 #include <config.h>
@@ -25,20 +23,25 @@
 #include <errno.h>
 
 #include <glib.h>
-#include <glib/gthread.h>
 
 #include <gtk/gtk.h>
 
+#include "games-runtime.h"
 #include "games-card-theme.h"
+#include "games-card-themes.h"
+#include "games-card-theme-private.h"
+#include "games-string-utils.h"
 
 int
 main (int argc, char *argv[])
 {
   GError *err = NULL;
-  char *basepath = NULL, *kfname, *kfpath;
+  char *basepath = NULL, *kfname, *kfpath, *theme_filename;
+  GamesCardThemeInfo *theme_info = NULL;
+  GamesCardThemes *theme_manager = NULL;
   GamesCardTheme *theme = NULL;
   GKeyFile *key_file = NULL;
-  guint i;
+  int i;
   int retval = EXIT_FAILURE;
   int *sizes = NULL, n_sizes = 0;
   char *data = NULL;
@@ -52,9 +55,9 @@ main (int argc, char *argv[])
   const GOptionEntry options[] = {
     { "theme", 't', 0, G_OPTION_ARG_STRING, &theme_name,
       "Select the theme to render", "NAME" },
-    { "theme-directory", 'd', 0, G_OPTION_ARG_STRING, &theme_dir,
+    { "theme-directory", 'd', 0, G_OPTION_ARG_FILENAME, &theme_dir,
       "The directory where the scalable card themes are installed", "DIR" },
-    { "output-directory", 'o', 0, G_OPTION_ARG_STRING, &outpath,
+    { "output-directory", 'o', 0, G_OPTION_ARG_FILENAME, &outpath,
       "Select the output root directoy", "DIR" },
     { "antialias", 'a', 0, G_OPTION_ARG_STRING, &antialias,
       "Enable antialiasing", NULL },
@@ -65,16 +68,12 @@ main (int argc, char *argv[])
     { NULL }
   };
 
-#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
-  /* If we're going to use gnome-vfs, we need to init threads before
-   * calling any glib functions.
-   */
-  g_thread_init (NULL);
-#endif
+  if (!games_runtime_init ("aisleriot"))
+    exit (1);
 
   if (!gtk_init_with_args
       (&argc, &argv, NULL, (GOptionEntry *) options, NULL, &err)) {
-    g_print ("Error parsing arguments: %s\n", err->message);
+    g_printerr ("Error parsing arguments: %s\n", err->message);
     g_error_free (err);
     goto loser;
   }
@@ -91,7 +90,7 @@ main (int argc, char *argv[])
     } else if (g_ascii_strcasecmp (subpixel_order, "vbgr") == 0) {
       subpixels = CAIRO_SUBPIXEL_ORDER_VBGR;
     } else {
-      g_print
+      g_printerr
         ("Unknown subpixel order '%s' specified. Valid orders are none, rgb, bgr, vrgb, vbgr.\n",
          subpixel_order);
       goto loser;
@@ -108,7 +107,7 @@ main (int argc, char *argv[])
     } else if (g_ascii_strcasecmp (antialias, "subpixel") == 0) {
       antialias_mode = CAIRO_ANTIALIAS_SUBPIXEL;
     } else {
-      g_print
+      g_printerr
         ("Unknown antialias mode '%s' specified. Valid modes are default, none, grey and subpixel.\n",
          antialias);
       goto loser;
@@ -117,28 +116,44 @@ main (int argc, char *argv[])
   }
 
   if (!outpath) {
-    g_print ("No output directory specified.\n");
+    g_printerr ("No output directory specified.\n");
     goto loser;
   }
 
   if (!theme_name) {
-    g_print ("No card theme specified.\n");
+    g_printerr ("No card theme specified.\n");
     goto loser;
   }
 
   if (!args) {
-    g_print ("No output size(s) specified.\n");
+    g_printerr ("No output size(s) specified.\n");
+    goto loser;
+  }
+
+  theme_filename = g_strdup_printf ("%s.svg", theme_name);
+  theme_info = _games_card_theme_info_new (GAMES_TYPE_CARD_THEME_SVG,
+                                           theme_dir ? theme_dir : games_runtime_get_directory (GAMES_RUNTIME_SCALABLE_CARDS_DIRECTORY),
+                                           theme_filename,
+                                           games_filename_to_display_name (theme_name),
+                                           g_strdup_printf ("svg:%s", theme_filename) /* FIXMEchpe is this correct? */,
+                                           NULL, NULL);
+  g_free (theme_filename);
+  theme_manager = games_card_themes_new ();
+  theme = games_card_themes_get_theme (theme_manager, theme_info);
+  if (!theme) {
+    /* FIXMEchpe print real error */
+    g_printerr ("Failed to load theme '%s'\n", theme_name);
     goto loser;
   }
 
-  theme = games_card_theme_new (NULL, TRUE);
   if (antialias_set) {
-    games_card_theme_set_antialias (theme, antialias_mode, subpixels);
-  }
+    cairo_font_options_t *font_options;
 
-  if (!games_card_theme_set_theme (theme, theme_name)) {
-    g_warning ("Failed to load theme '%s'\n", theme_name);
-    goto loser;
+    font_options = cairo_font_options_create ();
+    cairo_font_options_set_antialias (font_options, antialias_mode);
+    cairo_font_options_set_subpixel_order (font_options, subpixels);
+    games_card_theme_set_font_options (theme, font_options);
+    cairo_font_options_destroy (font_options);
   }
 
   if (g_mkdir_with_parents (outpath, 0755) < 0) {
@@ -207,7 +222,7 @@ main (int argc, char *argv[])
 
     sizes[i] = size;
 
-    card_size = games_card_theme_get_size (theme);
+    games_card_theme_get_size (theme, &card_size);
     g_key_file_set_integer (key_file, sizestr, "Width", card_size.width);
     g_key_file_set_integer (key_file, sizestr, "Height", card_size.height);
   }
@@ -247,6 +262,10 @@ loser:
   g_strfreev (args);
   if (theme)
     g_object_unref (theme);
+  if (theme_info)
+    games_card_theme_info_unref (theme_info);
+  if (theme_manager)
+    g_object_unref (theme_manager);
   if (key_file)
     g_key_file_free (key_file);
 
